/*******************************************************************************
* File Name: DDS_ClockDac.h
* Version 2.0
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_DDS_ClockDac_H)
#define CY_CLOCK_DDS_ClockDac_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_0 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void DDS_ClockDac_Start(void) ;
void DDS_ClockDac_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void DDS_ClockDac_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void DDS_ClockDac_StandbyPower(uint8 state) ;
void DDS_ClockDac_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 DDS_ClockDac_GetDividerRegister(void) ;
void DDS_ClockDac_SetModeRegister(uint8 modeBitMask) ;
void DDS_ClockDac_ClearModeRegister(uint8 modeBitMask) ;
uint8 DDS_ClockDac_GetModeRegister(void) ;
void DDS_ClockDac_SetSourceRegister(uint8 clkSource) ;
uint8 DDS_ClockDac_GetSourceRegister(void) ;
#if defined(DDS_ClockDac__CFG3)
void DDS_ClockDac_SetPhaseRegister(uint8 clkPhase) ;
uint8 DDS_ClockDac_GetPhaseRegister(void) ;
#endif /* defined(DDS_ClockDac__CFG3) */

#define DDS_ClockDac_Enable()                       DDS_ClockDac_Start()
#define DDS_ClockDac_Disable()                      DDS_ClockDac_Stop()
#define DDS_ClockDac_SetDivider(clkDivider)         DDS_ClockDac_SetDividerRegister(clkDivider, 1)
#define DDS_ClockDac_SetDividerValue(clkDivider)    DDS_ClockDac_SetDividerRegister((clkDivider) - 1, 1)
#define DDS_ClockDac_SetMode(clkMode)               DDS_ClockDac_SetModeRegister(clkMode)
#define DDS_ClockDac_SetSource(clkSource)           DDS_ClockDac_SetSourceRegister(clkSource)
#if defined(DDS_ClockDac__CFG3)
#define DDS_ClockDac_SetPhase(clkPhase)             DDS_ClockDac_SetPhaseRegister(clkPhase)
#define DDS_ClockDac_SetPhaseValue(clkPhase)        DDS_ClockDac_SetPhaseRegister((clkPhase) + 1)
#endif /* defined(DDS_ClockDac__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define DDS_ClockDac_CLKEN              (* (reg8 *) DDS_ClockDac__PM_ACT_CFG)
#define DDS_ClockDac_CLKEN_PTR          ((reg8 *) DDS_ClockDac__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define DDS_ClockDac_CLKSTBY            (* (reg8 *) DDS_ClockDac__PM_STBY_CFG)
#define DDS_ClockDac_CLKSTBY_PTR        ((reg8 *) DDS_ClockDac__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define DDS_ClockDac_DIV_LSB            (* (reg8 *) DDS_ClockDac__CFG0)
#define DDS_ClockDac_DIV_LSB_PTR        ((reg8 *) DDS_ClockDac__CFG0)
#define DDS_ClockDac_DIV_PTR            ((reg16 *) DDS_ClockDac__CFG0)

/* Clock MSB divider configuration register. */
#define DDS_ClockDac_DIV_MSB            (* (reg8 *) DDS_ClockDac__CFG1)
#define DDS_ClockDac_DIV_MSB_PTR        ((reg8 *) DDS_ClockDac__CFG1)

/* Mode and source configuration register */
#define DDS_ClockDac_MOD_SRC            (* (reg8 *) DDS_ClockDac__CFG2)
#define DDS_ClockDac_MOD_SRC_PTR        ((reg8 *) DDS_ClockDac__CFG2)

#if defined(DDS_ClockDac__CFG3)
/* Analog clock phase configuration register */
#define DDS_ClockDac_PHASE              (* (reg8 *) DDS_ClockDac__CFG3)
#define DDS_ClockDac_PHASE_PTR          ((reg8 *) DDS_ClockDac__CFG3)
#endif /* defined(DDS_ClockDac__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define DDS_ClockDac_CLKEN_MASK         DDS_ClockDac__PM_ACT_MSK
#define DDS_ClockDac_CLKSTBY_MASK       DDS_ClockDac__PM_STBY_MSK

/* CFG2 field masks */
#define DDS_ClockDac_SRC_SEL_MSK        DDS_ClockDac__CFG2_SRC_SEL_MASK
#define DDS_ClockDac_MODE_MASK          (~(DDS_ClockDac_SRC_SEL_MSK))

#if defined(DDS_ClockDac__CFG3)
/* CFG3 phase mask */
#define DDS_ClockDac_PHASE_MASK         DDS_ClockDac__CFG3_PHASE_DLY_MASK
#endif /* defined(DDS_ClockDac__CFG3) */

#endif /* CY_CLOCK_DDS_ClockDac_H */


/* [] END OF FILE */
