/*******************************************************************************
* File Name: DDS_DDS_IDAC.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  IDAC8.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include "DDS_DDS_IDAC.h"

static DDS_DDS_IDAC_backupStruct DDS_DDS_IDAC_backup;


/*******************************************************************************
* Function Name: DDS_DDS_IDAC_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void DDS_DDS_IDAC_SaveConfig(void) 
{
    if (!((DDS_DDS_IDAC_CR1 & DDS_DDS_IDAC_SRC_MASK) == DDS_DDS_IDAC_SRC_UDB))
    {
        DDS_DDS_IDAC_backup.data_value = DDS_DDS_IDAC_Data;
    }
}


/*******************************************************************************
* Function Name: DDS_DDS_IDAC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void DDS_DDS_IDAC_RestoreConfig(void) 
{
    if (!((DDS_DDS_IDAC_CR1 & DDS_DDS_IDAC_SRC_MASK) == DDS_DDS_IDAC_SRC_UDB))
    {
        if((DDS_DDS_IDAC_Strobe & DDS_DDS_IDAC_STRB_MASK) == DDS_DDS_IDAC_STRB_EN)
        {
            DDS_DDS_IDAC_Strobe &= (uint8)(~DDS_DDS_IDAC_STRB_MASK);
            DDS_DDS_IDAC_Data = DDS_DDS_IDAC_backup.data_value;
            DDS_DDS_IDAC_Strobe |= DDS_DDS_IDAC_STRB_EN;
        }
        else
        {
            DDS_DDS_IDAC_Data = DDS_DDS_IDAC_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: DDS_DDS_IDAC_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  DDS_DDS_IDAC_backup.enableState: Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DDS_DDS_IDAC_Sleep(void) 
{
    if(DDS_DDS_IDAC_ACT_PWR_EN == (DDS_DDS_IDAC_PWRMGR & DDS_DDS_IDAC_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        DDS_DDS_IDAC_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        DDS_DDS_IDAC_backup.enableState = 0u;
    }

    DDS_DDS_IDAC_Stop();
    DDS_DDS_IDAC_SaveConfig();
}


/*******************************************************************************
* Function Name: DDS_DDS_IDAC_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  DDS_DDS_IDAC_backup.enableState: Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DDS_DDS_IDAC_Wakeup(void) 
{
    DDS_DDS_IDAC_RestoreConfig();
    
    if(DDS_DDS_IDAC_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        DDS_DDS_IDAC_Enable();
        
        /* Set the data register */
        DDS_DDS_IDAC_SetValue(DDS_DDS_IDAC_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
