/*******************************************************************************
* File Name: DDS_iDAC.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  IDAC8.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include "DDS_iDAC.h"

static DDS_iDAC_backupStruct DDS_iDAC_backup;


/*******************************************************************************
* Function Name: DDS_iDAC_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void DDS_iDAC_SaveConfig(void) 
{
    if (!((DDS_iDAC_CR1 & DDS_iDAC_SRC_MASK) == DDS_iDAC_SRC_UDB))
    {
        DDS_iDAC_backup.data_value = DDS_iDAC_Data;
    }
}


/*******************************************************************************
* Function Name: DDS_iDAC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void DDS_iDAC_RestoreConfig(void) 
{
    if (!((DDS_iDAC_CR1 & DDS_iDAC_SRC_MASK) == DDS_iDAC_SRC_UDB))
    {
        if((DDS_iDAC_Strobe & DDS_iDAC_STRB_MASK) == DDS_iDAC_STRB_EN)
        {
            DDS_iDAC_Strobe &= (uint8)(~DDS_iDAC_STRB_MASK);
            DDS_iDAC_Data = DDS_iDAC_backup.data_value;
            DDS_iDAC_Strobe |= DDS_iDAC_STRB_EN;
        }
        else
        {
            DDS_iDAC_Data = DDS_iDAC_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: DDS_iDAC_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  DDS_iDAC_backup.enableState: Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DDS_iDAC_Sleep(void) 
{
    if(DDS_iDAC_ACT_PWR_EN == (DDS_iDAC_PWRMGR & DDS_iDAC_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        DDS_iDAC_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        DDS_iDAC_backup.enableState = 0u;
    }

    DDS_iDAC_Stop();
    DDS_iDAC_SaveConfig();
}


/*******************************************************************************
* Function Name: DDS_iDAC_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  DDS_iDAC_backup.enableState: Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DDS_iDAC_Wakeup(void) 
{
    DDS_iDAC_RestoreConfig();
    
    if(DDS_iDAC_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        DDS_iDAC_Enable();
        
        /* Set the data register */
        DDS_iDAC_SetValue(DDS_iDAC_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
