/*******************************************************************************
* File Name: DDSx_StatusPhase.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "DDSx_StatusPhase.h"

#if !defined(DDSx_StatusPhase_sts_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: DDSx_StatusPhase_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 DDSx_StatusPhase_Read(void) 
{ 
    return DDSx_StatusPhase_Status;
}


/*******************************************************************************
* Function Name: DDSx_StatusPhase_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DDSx_StatusPhase_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    DDSx_StatusPhase_Status_Aux_Ctrl |= DDSx_StatusPhase_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: DDSx_StatusPhase_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DDSx_StatusPhase_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    DDSx_StatusPhase_Status_Aux_Ctrl &= (uint8)(~DDSx_StatusPhase_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: DDSx_StatusPhase_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void DDSx_StatusPhase_WriteMask(uint8 mask) 
{
    #if(DDSx_StatusPhase_INPUTS < 8u)
    	mask &= (uint8)((((uint8)1u) << DDSx_StatusPhase_INPUTS) - 1u);
	#endif /* End DDSx_StatusPhase_INPUTS < 8u */
    DDSx_StatusPhase_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: DDSx_StatusPhase_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 DDSx_StatusPhase_ReadMask(void) 
{
    return DDSx_StatusPhase_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
