/*******************************************************************************
* File Name: DDSx_iDAC.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  IDAC8.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include "DDSx_iDAC.h"

static DDSx_iDAC_backupStruct DDSx_iDAC_backup;


/*******************************************************************************
* Function Name: DDSx_iDAC_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void DDSx_iDAC_SaveConfig(void) 
{
    if (!((DDSx_iDAC_CR1 & DDSx_iDAC_SRC_MASK) == DDSx_iDAC_SRC_UDB))
    {
        DDSx_iDAC_backup.data_value = DDSx_iDAC_Data;
    }
}


/*******************************************************************************
* Function Name: DDSx_iDAC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void DDSx_iDAC_RestoreConfig(void) 
{
    if (!((DDSx_iDAC_CR1 & DDSx_iDAC_SRC_MASK) == DDSx_iDAC_SRC_UDB))
    {
        if((DDSx_iDAC_Strobe & DDSx_iDAC_STRB_MASK) == DDSx_iDAC_STRB_EN)
        {
            DDSx_iDAC_Strobe &= (uint8)(~DDSx_iDAC_STRB_MASK);
            DDSx_iDAC_Data = DDSx_iDAC_backup.data_value;
            DDSx_iDAC_Strobe |= DDSx_iDAC_STRB_EN;
        }
        else
        {
            DDSx_iDAC_Data = DDSx_iDAC_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: DDSx_iDAC_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  DDSx_iDAC_backup.enableState: Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DDSx_iDAC_Sleep(void) 
{
    if(DDSx_iDAC_ACT_PWR_EN == (DDSx_iDAC_PWRMGR & DDSx_iDAC_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        DDSx_iDAC_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        DDSx_iDAC_backup.enableState = 0u;
    }

    DDSx_iDAC_Stop();
    DDSx_iDAC_SaveConfig();
}


/*******************************************************************************
* Function Name: DDSx_iDAC_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  DDSx_iDAC_backup.enableState: Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DDSx_iDAC_Wakeup(void) 
{
    DDSx_iDAC_RestoreConfig();
    
    if(DDSx_iDAC_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        DDSx_iDAC_Enable();
        
        /* Set the data register */
        DDSx_iDAC_SetValue(DDSx_iDAC_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
