/*******************************************************************************
* File Name: DDsClock.h
* Version 2.10
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_DDsClock_H)
#define CY_CLOCK_DDsClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void DDsClock_Start(void) ;
void DDsClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void DDsClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void DDsClock_StandbyPower(uint8 state) ;
void DDsClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 DDsClock_GetDividerRegister(void) ;
void DDsClock_SetModeRegister(uint8 modeBitMask) ;
void DDsClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 DDsClock_GetModeRegister(void) ;
void DDsClock_SetSourceRegister(uint8 clkSource) ;
uint8 DDsClock_GetSourceRegister(void) ;
#if defined(DDsClock__CFG3)
void DDsClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 DDsClock_GetPhaseRegister(void) ;
#endif /* defined(DDsClock__CFG3) */

#define DDsClock_Enable()                       DDsClock_Start()
#define DDsClock_Disable()                      DDsClock_Stop()
#define DDsClock_SetDivider(clkDivider)         DDsClock_SetDividerRegister(clkDivider, 1u)
#define DDsClock_SetDividerValue(clkDivider)    DDsClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define DDsClock_SetMode(clkMode)               DDsClock_SetModeRegister(clkMode)
#define DDsClock_SetSource(clkSource)           DDsClock_SetSourceRegister(clkSource)
#if defined(DDsClock__CFG3)
#define DDsClock_SetPhase(clkPhase)             DDsClock_SetPhaseRegister(clkPhase)
#define DDsClock_SetPhaseValue(clkPhase)        DDsClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(DDsClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define DDsClock_CLKEN              (* (reg8 *) DDsClock__PM_ACT_CFG)
#define DDsClock_CLKEN_PTR          ((reg8 *) DDsClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define DDsClock_CLKSTBY            (* (reg8 *) DDsClock__PM_STBY_CFG)
#define DDsClock_CLKSTBY_PTR        ((reg8 *) DDsClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define DDsClock_DIV_LSB            (* (reg8 *) DDsClock__CFG0)
#define DDsClock_DIV_LSB_PTR        ((reg8 *) DDsClock__CFG0)
#define DDsClock_DIV_PTR            ((reg16 *) DDsClock__CFG0)

/* Clock MSB divider configuration register. */
#define DDsClock_DIV_MSB            (* (reg8 *) DDsClock__CFG1)
#define DDsClock_DIV_MSB_PTR        ((reg8 *) DDsClock__CFG1)

/* Mode and source configuration register */
#define DDsClock_MOD_SRC            (* (reg8 *) DDsClock__CFG2)
#define DDsClock_MOD_SRC_PTR        ((reg8 *) DDsClock__CFG2)

#if defined(DDsClock__CFG3)
/* Analog clock phase configuration register */
#define DDsClock_PHASE              (* (reg8 *) DDsClock__CFG3)
#define DDsClock_PHASE_PTR          ((reg8 *) DDsClock__CFG3)
#endif /* defined(DDsClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define DDsClock_CLKEN_MASK         DDsClock__PM_ACT_MSK
#define DDsClock_CLKSTBY_MASK       DDsClock__PM_STBY_MSK

/* CFG2 field masks */
#define DDsClock_SRC_SEL_MSK        DDsClock__CFG2_SRC_SEL_MASK
#define DDsClock_MODE_MASK          (~(DDsClock_SRC_SEL_MSK))

#if defined(DDsClock__CFG3)
/* CFG3 phase mask */
#define DDsClock_PHASE_MASK         DDsClock__CFG3_PHASE_DLY_MASK
#endif /* defined(DDsClock__CFG3) */

#endif /* CY_CLOCK_DDsClock_H */


/* [] END OF FILE */
