/*******************************************************************************
* File Name: DacClock.h
* Version 2.10
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_DacClock_H)
#define CY_CLOCK_DacClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void DacClock_Start(void) ;
void DacClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void DacClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void DacClock_StandbyPower(uint8 state) ;
void DacClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 DacClock_GetDividerRegister(void) ;
void DacClock_SetModeRegister(uint8 modeBitMask) ;
void DacClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 DacClock_GetModeRegister(void) ;
void DacClock_SetSourceRegister(uint8 clkSource) ;
uint8 DacClock_GetSourceRegister(void) ;
#if defined(DacClock__CFG3)
void DacClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 DacClock_GetPhaseRegister(void) ;
#endif /* defined(DacClock__CFG3) */

#define DacClock_Enable()                       DacClock_Start()
#define DacClock_Disable()                      DacClock_Stop()
#define DacClock_SetDivider(clkDivider)         DacClock_SetDividerRegister(clkDivider, 1u)
#define DacClock_SetDividerValue(clkDivider)    DacClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define DacClock_SetMode(clkMode)               DacClock_SetModeRegister(clkMode)
#define DacClock_SetSource(clkSource)           DacClock_SetSourceRegister(clkSource)
#if defined(DacClock__CFG3)
#define DacClock_SetPhase(clkPhase)             DacClock_SetPhaseRegister(clkPhase)
#define DacClock_SetPhaseValue(clkPhase)        DacClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(DacClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define DacClock_CLKEN              (* (reg8 *) DacClock__PM_ACT_CFG)
#define DacClock_CLKEN_PTR          ((reg8 *) DacClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define DacClock_CLKSTBY            (* (reg8 *) DacClock__PM_STBY_CFG)
#define DacClock_CLKSTBY_PTR        ((reg8 *) DacClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define DacClock_DIV_LSB            (* (reg8 *) DacClock__CFG0)
#define DacClock_DIV_LSB_PTR        ((reg8 *) DacClock__CFG0)
#define DacClock_DIV_PTR            ((reg16 *) DacClock__CFG0)

/* Clock MSB divider configuration register. */
#define DacClock_DIV_MSB            (* (reg8 *) DacClock__CFG1)
#define DacClock_DIV_MSB_PTR        ((reg8 *) DacClock__CFG1)

/* Mode and source configuration register */
#define DacClock_MOD_SRC            (* (reg8 *) DacClock__CFG2)
#define DacClock_MOD_SRC_PTR        ((reg8 *) DacClock__CFG2)

#if defined(DacClock__CFG3)
/* Analog clock phase configuration register */
#define DacClock_PHASE              (* (reg8 *) DacClock__CFG3)
#define DacClock_PHASE_PTR          ((reg8 *) DacClock__CFG3)
#endif /* defined(DacClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define DacClock_CLKEN_MASK         DacClock__PM_ACT_MSK
#define DacClock_CLKSTBY_MASK       DacClock__PM_STBY_MSK

/* CFG2 field masks */
#define DacClock_SRC_SEL_MSK        DacClock__CFG2_SRC_SEL_MASK
#define DacClock_MODE_MASK          (~(DacClock_SRC_SEL_MSK))

#if defined(DacClock__CFG3)
/* CFG3 phase mask */
#define DacClock_PHASE_MASK         DacClock__CFG3_PHASE_DLY_MASK
#endif /* defined(DacClock__CFG3) */

#endif /* CY_CLOCK_DacClock_H */


/* [] END OF FILE */
