/*******************************************************************************
* File Name: GenClock.h
* Version 2.10
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_GenClock_H)
#define CY_CLOCK_GenClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void GenClock_Start(void) ;
void GenClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void GenClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void GenClock_StandbyPower(uint8 state) ;
void GenClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 GenClock_GetDividerRegister(void) ;
void GenClock_SetModeRegister(uint8 modeBitMask) ;
void GenClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 GenClock_GetModeRegister(void) ;
void GenClock_SetSourceRegister(uint8 clkSource) ;
uint8 GenClock_GetSourceRegister(void) ;
#if defined(GenClock__CFG3)
void GenClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 GenClock_GetPhaseRegister(void) ;
#endif /* defined(GenClock__CFG3) */

#define GenClock_Enable()                       GenClock_Start()
#define GenClock_Disable()                      GenClock_Stop()
#define GenClock_SetDivider(clkDivider)         GenClock_SetDividerRegister(clkDivider, 1u)
#define GenClock_SetDividerValue(clkDivider)    GenClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define GenClock_SetMode(clkMode)               GenClock_SetModeRegister(clkMode)
#define GenClock_SetSource(clkSource)           GenClock_SetSourceRegister(clkSource)
#if defined(GenClock__CFG3)
#define GenClock_SetPhase(clkPhase)             GenClock_SetPhaseRegister(clkPhase)
#define GenClock_SetPhaseValue(clkPhase)        GenClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(GenClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define GenClock_CLKEN              (* (reg8 *) GenClock__PM_ACT_CFG)
#define GenClock_CLKEN_PTR          ((reg8 *) GenClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define GenClock_CLKSTBY            (* (reg8 *) GenClock__PM_STBY_CFG)
#define GenClock_CLKSTBY_PTR        ((reg8 *) GenClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define GenClock_DIV_LSB            (* (reg8 *) GenClock__CFG0)
#define GenClock_DIV_LSB_PTR        ((reg8 *) GenClock__CFG0)
#define GenClock_DIV_PTR            ((reg16 *) GenClock__CFG0)

/* Clock MSB divider configuration register. */
#define GenClock_DIV_MSB            (* (reg8 *) GenClock__CFG1)
#define GenClock_DIV_MSB_PTR        ((reg8 *) GenClock__CFG1)

/* Mode and source configuration register */
#define GenClock_MOD_SRC            (* (reg8 *) GenClock__CFG2)
#define GenClock_MOD_SRC_PTR        ((reg8 *) GenClock__CFG2)

#if defined(GenClock__CFG3)
/* Analog clock phase configuration register */
#define GenClock_PHASE              (* (reg8 *) GenClock__CFG3)
#define GenClock_PHASE_PTR          ((reg8 *) GenClock__CFG3)
#endif /* defined(GenClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define GenClock_CLKEN_MASK         GenClock__PM_ACT_MSK
#define GenClock_CLKSTBY_MASK       GenClock__PM_STBY_MSK

/* CFG2 field masks */
#define GenClock_SRC_SEL_MSK        GenClock__CFG2_SRC_SEL_MASK
#define GenClock_MODE_MASK          (~(GenClock_SRC_SEL_MSK))

#if defined(GenClock__CFG3)
/* CFG3 phase mask */
#define GenClock_PHASE_MASK         GenClock__CFG3_PHASE_DLY_MASK
#endif /* defined(GenClock__CFG3) */

#endif /* CY_CLOCK_GenClock_H */


/* [] END OF FILE */
