/*******************************************************************************
* File Name: PhDet1_DacClock.h
* Version 2.10
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_PhDet1_DacClock_H)
#define CY_CLOCK_PhDet1_DacClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void PhDet1_DacClock_Start(void) ;
void PhDet1_DacClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void PhDet1_DacClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void PhDet1_DacClock_StandbyPower(uint8 state) ;
void PhDet1_DacClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 PhDet1_DacClock_GetDividerRegister(void) ;
void PhDet1_DacClock_SetModeRegister(uint8 modeBitMask) ;
void PhDet1_DacClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 PhDet1_DacClock_GetModeRegister(void) ;
void PhDet1_DacClock_SetSourceRegister(uint8 clkSource) ;
uint8 PhDet1_DacClock_GetSourceRegister(void) ;
#if defined(PhDet1_DacClock__CFG3)
void PhDet1_DacClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 PhDet1_DacClock_GetPhaseRegister(void) ;
#endif /* defined(PhDet1_DacClock__CFG3) */

#define PhDet1_DacClock_Enable()                       PhDet1_DacClock_Start()
#define PhDet1_DacClock_Disable()                      PhDet1_DacClock_Stop()
#define PhDet1_DacClock_SetDivider(clkDivider)         PhDet1_DacClock_SetDividerRegister(clkDivider, 1u)
#define PhDet1_DacClock_SetDividerValue(clkDivider)    PhDet1_DacClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define PhDet1_DacClock_SetMode(clkMode)               PhDet1_DacClock_SetModeRegister(clkMode)
#define PhDet1_DacClock_SetSource(clkSource)           PhDet1_DacClock_SetSourceRegister(clkSource)
#if defined(PhDet1_DacClock__CFG3)
#define PhDet1_DacClock_SetPhase(clkPhase)             PhDet1_DacClock_SetPhaseRegister(clkPhase)
#define PhDet1_DacClock_SetPhaseValue(clkPhase)        PhDet1_DacClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(PhDet1_DacClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define PhDet1_DacClock_CLKEN              (* (reg8 *) PhDet1_DacClock__PM_ACT_CFG)
#define PhDet1_DacClock_CLKEN_PTR          ((reg8 *) PhDet1_DacClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define PhDet1_DacClock_CLKSTBY            (* (reg8 *) PhDet1_DacClock__PM_STBY_CFG)
#define PhDet1_DacClock_CLKSTBY_PTR        ((reg8 *) PhDet1_DacClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define PhDet1_DacClock_DIV_LSB            (* (reg8 *) PhDet1_DacClock__CFG0)
#define PhDet1_DacClock_DIV_LSB_PTR        ((reg8 *) PhDet1_DacClock__CFG0)
#define PhDet1_DacClock_DIV_PTR            ((reg16 *) PhDet1_DacClock__CFG0)

/* Clock MSB divider configuration register. */
#define PhDet1_DacClock_DIV_MSB            (* (reg8 *) PhDet1_DacClock__CFG1)
#define PhDet1_DacClock_DIV_MSB_PTR        ((reg8 *) PhDet1_DacClock__CFG1)

/* Mode and source configuration register */
#define PhDet1_DacClock_MOD_SRC            (* (reg8 *) PhDet1_DacClock__CFG2)
#define PhDet1_DacClock_MOD_SRC_PTR        ((reg8 *) PhDet1_DacClock__CFG2)

#if defined(PhDet1_DacClock__CFG3)
/* Analog clock phase configuration register */
#define PhDet1_DacClock_PHASE              (* (reg8 *) PhDet1_DacClock__CFG3)
#define PhDet1_DacClock_PHASE_PTR          ((reg8 *) PhDet1_DacClock__CFG3)
#endif /* defined(PhDet1_DacClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define PhDet1_DacClock_CLKEN_MASK         PhDet1_DacClock__PM_ACT_MSK
#define PhDet1_DacClock_CLKSTBY_MASK       PhDet1_DacClock__PM_STBY_MSK

/* CFG2 field masks */
#define PhDet1_DacClock_SRC_SEL_MSK        PhDet1_DacClock__CFG2_SRC_SEL_MASK
#define PhDet1_DacClock_MODE_MASK          (~(PhDet1_DacClock_SRC_SEL_MSK))

#if defined(PhDet1_DacClock__CFG3)
/* CFG3 phase mask */
#define PhDet1_DacClock_PHASE_MASK         PhDet1_DacClock__CFG3_PHASE_DLY_MASK
#endif /* defined(PhDet1_DacClock__CFG3) */

#endif /* CY_CLOCK_PhDet1_DacClock_H */


/* [] END OF FILE */
