/*******************************************************************************
* File Name: PhDet1_PhaseClock.h
* Version 2.10
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_PhDet1_PhaseClock_H)
#define CY_CLOCK_PhDet1_PhaseClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void PhDet1_PhaseClock_Start(void) ;
void PhDet1_PhaseClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void PhDet1_PhaseClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void PhDet1_PhaseClock_StandbyPower(uint8 state) ;
void PhDet1_PhaseClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 PhDet1_PhaseClock_GetDividerRegister(void) ;
void PhDet1_PhaseClock_SetModeRegister(uint8 modeBitMask) ;
void PhDet1_PhaseClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 PhDet1_PhaseClock_GetModeRegister(void) ;
void PhDet1_PhaseClock_SetSourceRegister(uint8 clkSource) ;
uint8 PhDet1_PhaseClock_GetSourceRegister(void) ;
#if defined(PhDet1_PhaseClock__CFG3)
void PhDet1_PhaseClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 PhDet1_PhaseClock_GetPhaseRegister(void) ;
#endif /* defined(PhDet1_PhaseClock__CFG3) */

#define PhDet1_PhaseClock_Enable()                       PhDet1_PhaseClock_Start()
#define PhDet1_PhaseClock_Disable()                      PhDet1_PhaseClock_Stop()
#define PhDet1_PhaseClock_SetDivider(clkDivider)         PhDet1_PhaseClock_SetDividerRegister(clkDivider, 1u)
#define PhDet1_PhaseClock_SetDividerValue(clkDivider)    PhDet1_PhaseClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define PhDet1_PhaseClock_SetMode(clkMode)               PhDet1_PhaseClock_SetModeRegister(clkMode)
#define PhDet1_PhaseClock_SetSource(clkSource)           PhDet1_PhaseClock_SetSourceRegister(clkSource)
#if defined(PhDet1_PhaseClock__CFG3)
#define PhDet1_PhaseClock_SetPhase(clkPhase)             PhDet1_PhaseClock_SetPhaseRegister(clkPhase)
#define PhDet1_PhaseClock_SetPhaseValue(clkPhase)        PhDet1_PhaseClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(PhDet1_PhaseClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define PhDet1_PhaseClock_CLKEN              (* (reg8 *) PhDet1_PhaseClock__PM_ACT_CFG)
#define PhDet1_PhaseClock_CLKEN_PTR          ((reg8 *) PhDet1_PhaseClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define PhDet1_PhaseClock_CLKSTBY            (* (reg8 *) PhDet1_PhaseClock__PM_STBY_CFG)
#define PhDet1_PhaseClock_CLKSTBY_PTR        ((reg8 *) PhDet1_PhaseClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define PhDet1_PhaseClock_DIV_LSB            (* (reg8 *) PhDet1_PhaseClock__CFG0)
#define PhDet1_PhaseClock_DIV_LSB_PTR        ((reg8 *) PhDet1_PhaseClock__CFG0)
#define PhDet1_PhaseClock_DIV_PTR            ((reg16 *) PhDet1_PhaseClock__CFG0)

/* Clock MSB divider configuration register. */
#define PhDet1_PhaseClock_DIV_MSB            (* (reg8 *) PhDet1_PhaseClock__CFG1)
#define PhDet1_PhaseClock_DIV_MSB_PTR        ((reg8 *) PhDet1_PhaseClock__CFG1)

/* Mode and source configuration register */
#define PhDet1_PhaseClock_MOD_SRC            (* (reg8 *) PhDet1_PhaseClock__CFG2)
#define PhDet1_PhaseClock_MOD_SRC_PTR        ((reg8 *) PhDet1_PhaseClock__CFG2)

#if defined(PhDet1_PhaseClock__CFG3)
/* Analog clock phase configuration register */
#define PhDet1_PhaseClock_PHASE              (* (reg8 *) PhDet1_PhaseClock__CFG3)
#define PhDet1_PhaseClock_PHASE_PTR          ((reg8 *) PhDet1_PhaseClock__CFG3)
#endif /* defined(PhDet1_PhaseClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define PhDet1_PhaseClock_CLKEN_MASK         PhDet1_PhaseClock__PM_ACT_MSK
#define PhDet1_PhaseClock_CLKSTBY_MASK       PhDet1_PhaseClock__PM_STBY_MSK

/* CFG2 field masks */
#define PhDet1_PhaseClock_SRC_SEL_MSK        PhDet1_PhaseClock__CFG2_SRC_SEL_MASK
#define PhDet1_PhaseClock_MODE_MASK          (~(PhDet1_PhaseClock_SRC_SEL_MSK))

#if defined(PhDet1_PhaseClock__CFG3)
/* CFG3 phase mask */
#define PhDet1_PhaseClock_PHASE_MASK         PhDet1_PhaseClock__CFG3_PHASE_DLY_MASK
#endif /* defined(PhDet1_PhaseClock__CFG3) */

#endif /* CY_CLOCK_PhDet1_PhaseClock_H */


/* [] END OF FILE */
