/*******************************************************************************
* File Name: PhDet1_UpDnCounter.c  
* Version 2.40
*
*  Description:
*     The Counter component consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "PhDet1_UpDnCounter.h"

uint8 PhDet1_UpDnCounter_initVar = 0u;


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void PhDet1_UpDnCounter_Init(void) 
{
        #if (!PhDet1_UpDnCounter_UsingFixedFunction && !PhDet1_UpDnCounter_ControlRegRemoved)
            uint8 ctrl;
        #endif /* (!PhDet1_UpDnCounter_UsingFixedFunction && !PhDet1_UpDnCounter_ControlRegRemoved) */
        
        #if(!PhDet1_UpDnCounter_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 PhDet1_UpDnCounter_interruptState;
        #endif /* (!PhDet1_UpDnCounter_UsingFixedFunction) */
        
        #if (PhDet1_UpDnCounter_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            PhDet1_UpDnCounter_CONTROL &= PhDet1_UpDnCounter_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (CY_PSOC5A)
                PhDet1_UpDnCounter_CONTROL2 &= ((uint8)(~PhDet1_UpDnCounter_CTRL_MODE_MASK));
            #endif /* (CY_PSOC5A) */
            #if (CY_PSOC3 || CY_PSOC5LP)
                PhDet1_UpDnCounter_CONTROL3 &= ((uint8)(~PhDet1_UpDnCounter_CTRL_MODE_MASK));                
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (PhDet1_UpDnCounter_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                PhDet1_UpDnCounter_CONTROL |= PhDet1_UpDnCounter_ONESHOT;
            #endif /* (PhDet1_UpDnCounter_RunModeUsed != 0x0u) */
            
            /* Set the IRQ to use the status register interrupts */
            PhDet1_UpDnCounter_CONTROL2 |= PhDet1_UpDnCounter_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            PhDet1_UpDnCounter_RT1 &= ((uint8)(~PhDet1_UpDnCounter_RT1_MASK));
            PhDet1_UpDnCounter_RT1 |= PhDet1_UpDnCounter_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            PhDet1_UpDnCounter_RT1 &= ((uint8)(~PhDet1_UpDnCounter_SYNCDSI_MASK));
            PhDet1_UpDnCounter_RT1 |= PhDet1_UpDnCounter_SYNCDSI_EN;

        #else
            #if(!PhDet1_UpDnCounter_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = PhDet1_UpDnCounter_CONTROL & ((uint8)(~PhDet1_UpDnCounter_CTRL_CMPMODE_MASK));
            PhDet1_UpDnCounter_CONTROL = ctrl | PhDet1_UpDnCounter_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = PhDet1_UpDnCounter_CONTROL & ((uint8)(~PhDet1_UpDnCounter_CTRL_CAPMODE_MASK));
            
            #if( 0 != PhDet1_UpDnCounter_CAPTURE_MODE_CONF)
                PhDet1_UpDnCounter_CONTROL = ctrl | PhDet1_UpDnCounter_DEFAULT_CAPTURE_MODE;
            #else
                PhDet1_UpDnCounter_CONTROL = ctrl;
            #endif /* 0 != PhDet1_UpDnCounter_CAPTURE_MODE */ 
            
            #endif /* (!PhDet1_UpDnCounter_ControlRegRemoved) */
        #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
        
        /* Clear all data in the FIFO's */
        #if (!PhDet1_UpDnCounter_UsingFixedFunction)
            PhDet1_UpDnCounter_ClearFIFO();
        #endif /* (!PhDet1_UpDnCounter_UsingFixedFunction) */
        
        /* Set Initial values from Configuration */
        PhDet1_UpDnCounter_WritePeriod(PhDet1_UpDnCounter_INIT_PERIOD_VALUE);
        #if (!(PhDet1_UpDnCounter_UsingFixedFunction && (CY_PSOC5A)))
            PhDet1_UpDnCounter_WriteCounter(PhDet1_UpDnCounter_INIT_COUNTER_VALUE);
        #endif /* (!(PhDet1_UpDnCounter_UsingFixedFunction && (CY_PSOC5A))) */
        PhDet1_UpDnCounter_SetInterruptMode(PhDet1_UpDnCounter_INIT_INTERRUPTS_MASK);
        
        #if (!PhDet1_UpDnCounter_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            (void)PhDet1_UpDnCounter_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            PhDet1_UpDnCounter_WriteCompare(PhDet1_UpDnCounter_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            PhDet1_UpDnCounter_interruptState = CyEnterCriticalSection();
            
            PhDet1_UpDnCounter_STATUS_AUX_CTRL |= PhDet1_UpDnCounter_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(PhDet1_UpDnCounter_interruptState);
            
        #endif /* (!PhDet1_UpDnCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
*******************************************************************************/
void PhDet1_UpDnCounter_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (PhDet1_UpDnCounter_UsingFixedFunction)
        PhDet1_UpDnCounter_GLOBAL_ENABLE |= PhDet1_UpDnCounter_BLOCK_EN_MASK;
        PhDet1_UpDnCounter_GLOBAL_STBY_ENABLE |= PhDet1_UpDnCounter_BLOCK_STBY_EN_MASK;
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */  
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!PhDet1_UpDnCounter_ControlRegRemoved || PhDet1_UpDnCounter_UsingFixedFunction)
        PhDet1_UpDnCounter_CONTROL |= PhDet1_UpDnCounter_CTRL_ENABLE;                
    #endif /* (!PhDet1_UpDnCounter_ControlRegRemoved || PhDet1_UpDnCounter_UsingFixedFunction) */
    
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  PhDet1_UpDnCounter_initVar: Is modified when this function is called for the  
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void PhDet1_UpDnCounter_Start(void) 
{
    if(PhDet1_UpDnCounter_initVar == 0u)
    {
        PhDet1_UpDnCounter_Init();
        
        PhDet1_UpDnCounter_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    PhDet1_UpDnCounter_Enable();        
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
*******************************************************************************/
void PhDet1_UpDnCounter_Stop(void) 
{
    /* Disable Counter */
    #if(!PhDet1_UpDnCounter_ControlRegRemoved || PhDet1_UpDnCounter_UsingFixedFunction)
        PhDet1_UpDnCounter_CONTROL &= ((uint8)(~PhDet1_UpDnCounter_CTRL_ENABLE));        
    #endif /* (!PhDet1_UpDnCounter_ControlRegRemoved || PhDet1_UpDnCounter_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (PhDet1_UpDnCounter_UsingFixedFunction)
        PhDet1_UpDnCounter_GLOBAL_ENABLE &= ((uint8)(~PhDet1_UpDnCounter_BLOCK_EN_MASK));
        PhDet1_UpDnCounter_GLOBAL_STBY_ENABLE &= ((uint8)(~PhDet1_UpDnCounter_BLOCK_STBY_EN_MASK));
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
*******************************************************************************/
void PhDet1_UpDnCounter_SetInterruptMode(uint8 interruptsMask) 
{
    PhDet1_UpDnCounter_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
*******************************************************************************/
uint8   PhDet1_UpDnCounter_ReadStatusRegister(void) 
{
    return PhDet1_UpDnCounter_STATUS;
}


#if(!PhDet1_UpDnCounter_ControlRegRemoved)
/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
uint8   PhDet1_UpDnCounter_ReadControlRegister(void) 
{
    return PhDet1_UpDnCounter_CONTROL;
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
void    PhDet1_UpDnCounter_WriteControlRegister(uint8 control) 
{
    PhDet1_UpDnCounter_CONTROL = control;
}

#endif  /* (!PhDet1_UpDnCounter_ControlRegRemoved) */


#if (!(PhDet1_UpDnCounter_UsingFixedFunction && (CY_PSOC5A)))
/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
*******************************************************************************/
void PhDet1_UpDnCounter_WriteCounter(uint16 counter) \
                                   
{
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
        /* assert if block is already enabled */
        CYASSERT (0u == (PhDet1_UpDnCounter_GLOBAL_ENABLE & PhDet1_UpDnCounter_BLOCK_EN_MASK));
        /* If block is disabled, enable it and then write the counter */
        PhDet1_UpDnCounter_GLOBAL_ENABLE |= PhDet1_UpDnCounter_BLOCK_EN_MASK;
        CY_SET_REG16(PhDet1_UpDnCounter_COUNTER_LSB_PTR, (uint16)counter);
        PhDet1_UpDnCounter_GLOBAL_ENABLE &= ((uint8)(~PhDet1_UpDnCounter_BLOCK_EN_MASK));
    #else
        CY_SET_REG16(PhDet1_UpDnCounter_COUNTER_LSB_PTR, counter);
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}
#endif /* (!(PhDet1_UpDnCounter_UsingFixedFunction && (CY_PSOC5A))) */


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint16) The present value of the counter.
*
*******************************************************************************/
uint16 PhDet1_UpDnCounter_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
		(void)CY_GET_REG16(PhDet1_UpDnCounter_COUNTER_LSB_PTR);
	#else
		(void)CY_GET_REG8(PhDet1_UpDnCounter_COUNTER_LSB_PTR_8BIT);
	#endif/* (PhDet1_UpDnCounter_UsingFixedFunction) */
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
        return ((uint16)CY_GET_REG16(PhDet1_UpDnCounter_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG16(PhDet1_UpDnCounter_STATICCOUNT_LSB_PTR));
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint16) Present Capture value.
*
*******************************************************************************/
uint16 PhDet1_UpDnCounter_ReadCapture(void) 
{
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
        return ((uint16)CY_GET_REG16(PhDet1_UpDnCounter_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG16(PhDet1_UpDnCounter_STATICCOUNT_LSB_PTR));
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint16) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
*******************************************************************************/
void PhDet1_UpDnCounter_WritePeriod(uint16 period) 
{
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
        CY_SET_REG16(PhDet1_UpDnCounter_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG16(PhDet1_UpDnCounter_PERIOD_LSB_PTR, period);
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint16) Present period value.
*
*******************************************************************************/
uint16 PhDet1_UpDnCounter_ReadPeriod(void) 
{
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
        return ((uint16)CY_GET_REG16(PhDet1_UpDnCounter_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG16(PhDet1_UpDnCounter_PERIOD_LSB_PTR));
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}


#if (!PhDet1_UpDnCounter_UsingFixedFunction)
/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
*******************************************************************************/
void PhDet1_UpDnCounter_WriteCompare(uint16 compare) \
                                   
{
    #if(PhDet1_UpDnCounter_UsingFixedFunction)
        CY_SET_REG16(PhDet1_UpDnCounter_COMPARE_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG16(PhDet1_UpDnCounter_COMPARE_LSB_PTR, compare);
    #endif /* (PhDet1_UpDnCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint16) Present compare value.
*
*******************************************************************************/
uint16 PhDet1_UpDnCounter_ReadCompare(void) 
{
    return (CY_GET_REG16(PhDet1_UpDnCounter_COMPARE_LSB_PTR));
}


#if (PhDet1_UpDnCounter_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void PhDet1_UpDnCounter_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    PhDet1_UpDnCounter_CONTROL &= ((uint8)(~PhDet1_UpDnCounter_CTRL_CMPMODE_MASK));
    
    /* Write the new setting */
    PhDet1_UpDnCounter_CONTROL |= compareMode;
}
#endif  /* (PhDet1_UpDnCounter_COMPARE_MODE_SOFTWARE) */


#if (PhDet1_UpDnCounter_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void PhDet1_UpDnCounter_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    PhDet1_UpDnCounter_CONTROL &= ((uint8)(~PhDet1_UpDnCounter_CTRL_CAPMODE_MASK));
    
    /* Write the new setting */
    PhDet1_UpDnCounter_CONTROL |= ((uint8)((uint8)captureMode << PhDet1_UpDnCounter_CTRL_CAPMODE0_SHIFT));
}
#endif  /* (PhDet1_UpDnCounter_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: PhDet1_UpDnCounter_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
*******************************************************************************/
void PhDet1_UpDnCounter_ClearFIFO(void) 
{

    while(0u != (PhDet1_UpDnCounter_ReadStatusRegister() & PhDet1_UpDnCounter_STATUS_FIFONEMP))
    {
        (void)PhDet1_UpDnCounter_ReadCapture();
    }

}
#endif  /* (!PhDet1_UpDnCounter_UsingFixedFunction) */


/* [] END OF FILE */

