/*******************************************************************************
* File Name: PhDet1_iDAC.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  IDAC8.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include "PhDet1_iDAC.h"

static PhDet1_iDAC_backupStruct PhDet1_iDAC_backup;


/*******************************************************************************
* Function Name: PhDet1_iDAC_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void PhDet1_iDAC_SaveConfig(void) 
{
    if (!((PhDet1_iDAC_CR1 & PhDet1_iDAC_SRC_MASK) == PhDet1_iDAC_SRC_UDB))
    {
        PhDet1_iDAC_backup.data_value = PhDet1_iDAC_Data;
    }
}


/*******************************************************************************
* Function Name: PhDet1_iDAC_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void PhDet1_iDAC_RestoreConfig(void) 
{
    if (!((PhDet1_iDAC_CR1 & PhDet1_iDAC_SRC_MASK) == PhDet1_iDAC_SRC_UDB))
    {
        if((PhDet1_iDAC_Strobe & PhDet1_iDAC_STRB_MASK) == PhDet1_iDAC_STRB_EN)
        {
            PhDet1_iDAC_Strobe &= (uint8)(~PhDet1_iDAC_STRB_MASK);
            PhDet1_iDAC_Data = PhDet1_iDAC_backup.data_value;
            PhDet1_iDAC_Strobe |= PhDet1_iDAC_STRB_EN;
        }
        else
        {
            PhDet1_iDAC_Data = PhDet1_iDAC_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: PhDet1_iDAC_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  PhDet1_iDAC_backup.enableState: Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void PhDet1_iDAC_Sleep(void) 
{
    if(PhDet1_iDAC_ACT_PWR_EN == (PhDet1_iDAC_PWRMGR & PhDet1_iDAC_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        PhDet1_iDAC_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        PhDet1_iDAC_backup.enableState = 0u;
    }

    PhDet1_iDAC_Stop();
    PhDet1_iDAC_SaveConfig();
}


/*******************************************************************************
* Function Name: PhDet1_iDAC_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  PhDet1_iDAC_backup.enableState: Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void PhDet1_iDAC_Wakeup(void) 
{
    PhDet1_iDAC_RestoreConfig();
    
    if(PhDet1_iDAC_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        PhDet1_iDAC_Enable();
        
        /* Set the data register */
        PhDet1_iDAC_SetValue(PhDet1_iDAC_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
