/*******************************************************************************
* File Name: PhaseGen1_PhasePWM.h  
* Version 3.0
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_PhaseGen1_PhasePWM_H)
#define CY_PWM_PhaseGen1_PhasePWM_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 PhaseGen1_PhasePWM_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define PhaseGen1_PhasePWM_Resolution 8u
#define PhaseGen1_PhasePWM_UsingFixedFunction 0u
#define PhaseGen1_PhasePWM_DeadBandMode 0u
#define PhaseGen1_PhasePWM_KillModeMinTime 0u
#define PhaseGen1_PhasePWM_KillMode 0u
#define PhaseGen1_PhasePWM_PWMMode 1u
#define PhaseGen1_PhasePWM_PWMModeIsCenterAligned 0u
#define PhaseGen1_PhasePWM_DeadBandUsed 0u
#define PhaseGen1_PhasePWM_DeadBand2_4 0u

#if !defined(PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__REMOVED)
    #define PhaseGen1_PhasePWM_UseStatus 0u
#else
    #define PhaseGen1_PhasePWM_UseStatus 0u
#endif /* !defined(PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(PhaseGen1_PhasePWM_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define PhaseGen1_PhasePWM_UseControl 1u
#else
    #define PhaseGen1_PhasePWM_UseControl 0u
#endif /* !defined(PhaseGen1_PhasePWM_PWMUDB_genblk1_ctrlreg__REMOVED) */
#define PhaseGen1_PhasePWM_UseOneCompareMode 0u
#define PhaseGen1_PhasePWM_MinimumKillTime 1u
#define PhaseGen1_PhasePWM_EnableMode 0u

#define PhaseGen1_PhasePWM_CompareMode1SW 0u
#define PhaseGen1_PhasePWM_CompareMode2SW 0u

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define PhaseGen1_PhasePWM__B_PWM__DISABLED 0
#define PhaseGen1_PhasePWM__B_PWM__ASYNCHRONOUS 1
#define PhaseGen1_PhasePWM__B_PWM__SINGLECYCLE 2
#define PhaseGen1_PhasePWM__B_PWM__LATCHED 3
#define PhaseGen1_PhasePWM__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define PhaseGen1_PhasePWM__B_PWM__DBMDISABLED 0
#define PhaseGen1_PhasePWM__B_PWM__DBM_2_4_CLOCKS 1
#define PhaseGen1_PhasePWM__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define PhaseGen1_PhasePWM__B_PWM__ONE_OUTPUT 0
#define PhaseGen1_PhasePWM__B_PWM__TWO_OUTPUTS 1
#define PhaseGen1_PhasePWM__B_PWM__DUAL_EDGE 2
#define PhaseGen1_PhasePWM__B_PWM__CENTER_ALIGN 3
#define PhaseGen1_PhasePWM__B_PWM__DITHER 5
#define PhaseGen1_PhasePWM__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define PhaseGen1_PhasePWM__B_PWM__LESS_THAN 1
#define PhaseGen1_PhasePWM__B_PWM__LESS_THAN_OR_EQUAL 2
#define PhaseGen1_PhasePWM__B_PWM__GREATER_THAN 3
#define PhaseGen1_PhasePWM__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define PhaseGen1_PhasePWM__B_PWM__EQUAL 0
#define PhaseGen1_PhasePWM__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{
    
    uint8 PWMEnableState;
       
    #if(!PhaseGen1_PhasePWM_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!PhaseGen1_PhasePWM_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!PhaseGen1_PhasePWM_PWMModeIsCenterAligned) */
        #if (PhaseGen1_PhasePWM_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (PhaseGen1_PhasePWM_UseStatus) */
        
        /* Backup for Deadband parameters */
        #if(PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_256_CLOCKS || \
            PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */
        
        /* Backup Kill Mode Counter*/
        #if(PhaseGen1_PhasePWM_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (PhaseGen1_PhasePWM_KillModeMinTime) */
       
        /* Backup control register */
        #if(PhaseGen1_PhasePWM_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (PhaseGen1_PhasePWM_UseControl) */
        
    #endif /* (!PhaseGen1_PhasePWM_UsingFixedFunction) */
   
}PhaseGen1_PhasePWM_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/
 
void    PhaseGen1_PhasePWM_Start(void) ;
void    PhaseGen1_PhasePWM_Stop(void) ;

#if (PhaseGen1_PhasePWM_UseStatus || PhaseGen1_PhasePWM_UsingFixedFunction)
    void  PhaseGen1_PhasePWM_SetInterruptMode(uint8 interruptMode) ;
    uint8 PhaseGen1_PhasePWM_ReadStatusRegister(void) ;
#endif /* (PhaseGen1_PhasePWM_UseStatus || PhaseGen1_PhasePWM_UsingFixedFunction) */

#define PhaseGen1_PhasePWM_GetInterruptSource() PhaseGen1_PhasePWM_ReadStatusRegister()

#if (PhaseGen1_PhasePWM_UseControl)
    uint8 PhaseGen1_PhasePWM_ReadControlRegister(void) ; 
    void  PhaseGen1_PhasePWM_WriteControlRegister(uint8 control) ;
#endif /* (PhaseGen1_PhasePWM_UseControl) */

#if (PhaseGen1_PhasePWM_UseOneCompareMode)
   #if (PhaseGen1_PhasePWM_CompareMode1SW)
       void    PhaseGen1_PhasePWM_SetCompareMode(uint8 comparemode) ;
   #endif /* (PhaseGen1_PhasePWM_CompareMode1SW) */
#else
    #if (PhaseGen1_PhasePWM_CompareMode1SW)
        void    PhaseGen1_PhasePWM_SetCompareMode1(uint8 comparemode) ;
    #endif /* (PhaseGen1_PhasePWM_CompareMode1SW) */
    #if (PhaseGen1_PhasePWM_CompareMode2SW)
        void    PhaseGen1_PhasePWM_SetCompareMode2(uint8 comparemode) ;
    #endif /* (PhaseGen1_PhasePWM_CompareMode2SW) */
#endif /* (PhaseGen1_PhasePWM_UseOneCompareMode) */

#if (!PhaseGen1_PhasePWM_UsingFixedFunction)
    uint8   PhaseGen1_PhasePWM_ReadCounter(void) ;
    uint8 PhaseGen1_PhasePWM_ReadCapture(void) ;
    
	#if (PhaseGen1_PhasePWM_UseStatus)
	        void PhaseGen1_PhasePWM_ClearFIFO(void) ;
	#endif /* (PhaseGen1_PhasePWM_UseStatus) */

    void    PhaseGen1_PhasePWM_WriteCounter(uint8 counter) ;
#endif /* (!PhaseGen1_PhasePWM_UsingFixedFunction) */

void    PhaseGen1_PhasePWM_WritePeriod(uint8 period) ;
uint8 PhaseGen1_PhasePWM_ReadPeriod(void) ;

#if (PhaseGen1_PhasePWM_UseOneCompareMode)
    void    PhaseGen1_PhasePWM_WriteCompare(uint8 compare) ;
    uint8 PhaseGen1_PhasePWM_ReadCompare(void) ; 
#else
    void    PhaseGen1_PhasePWM_WriteCompare1(uint8 compare) ;
    uint8 PhaseGen1_PhasePWM_ReadCompare1(void) ; 
    void    PhaseGen1_PhasePWM_WriteCompare2(uint8 compare) ;
    uint8 PhaseGen1_PhasePWM_ReadCompare2(void) ; 
#endif /* (PhaseGen1_PhasePWM_UseOneCompareMode) */


#if (PhaseGen1_PhasePWM_DeadBandUsed)
    void    PhaseGen1_PhasePWM_WriteDeadTime(uint8 deadtime) ;
    uint8   PhaseGen1_PhasePWM_ReadDeadTime(void) ;
#endif /* (PhaseGen1_PhasePWM_DeadBandUsed) */

#if ( PhaseGen1_PhasePWM_KillModeMinTime)
    void PhaseGen1_PhasePWM_WriteKillTime(uint8 killtime) ;
    uint8 PhaseGen1_PhasePWM_ReadKillTime(void) ; 
#endif /* ( PhaseGen1_PhasePWM_KillModeMinTime) */

void PhaseGen1_PhasePWM_Init(void) ;
void PhaseGen1_PhasePWM_Enable(void) ;
void PhaseGen1_PhasePWM_Sleep(void) ;
void PhaseGen1_PhasePWM_Wakeup(void) ;
void PhaseGen1_PhasePWM_SaveConfig(void) ;
void PhaseGen1_PhasePWM_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define PhaseGen1_PhasePWM_INIT_PERIOD_VALUE        49u
#define PhaseGen1_PhasePWM_INIT_COMPARE_VALUE1      40u
#define PhaseGen1_PhasePWM_INIT_COMPARE_VALUE2      38u
#define PhaseGen1_PhasePWM_INIT_INTERRUPTS_MODE     (uint8)(((uint8)(0u << PhaseGen1_PhasePWM_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << PhaseGen1_PhasePWM_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << PhaseGen1_PhasePWM_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                  (uint8)((uint8)(0u << PhaseGen1_PhasePWM_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define PhaseGen1_PhasePWM_DEFAULT_COMPARE2_MODE    (uint8)((uint8)2u << PhaseGen1_PhasePWM_CTRL_CMPMODE2_SHIFT)
#define PhaseGen1_PhasePWM_DEFAULT_COMPARE1_MODE    (uint8)((uint8)2u << PhaseGen1_PhasePWM_CTRL_CMPMODE1_SHIFT)
#define PhaseGen1_PhasePWM_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (PhaseGen1_PhasePWM_UsingFixedFunction)
   #define PhaseGen1_PhasePWM_PERIOD_LSB          (*(reg16 *) PhaseGen1_PhasePWM_PWMHW__PER0)
   #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR      ( (reg16 *) PhaseGen1_PhasePWM_PWMHW__PER0)
   #define PhaseGen1_PhasePWM_COMPARE1_LSB        (*(reg16 *) PhaseGen1_PhasePWM_PWMHW__CNT_CMP0)
   #define PhaseGen1_PhasePWM_COMPARE1_LSB_PTR    ( (reg16 *) PhaseGen1_PhasePWM_PWMHW__CNT_CMP0)
   #define PhaseGen1_PhasePWM_COMPARE2_LSB        0x00u
   #define PhaseGen1_PhasePWM_COMPARE2_LSB_PTR    0x00u
   #define PhaseGen1_PhasePWM_COUNTER_LSB         (*(reg16 *) PhaseGen1_PhasePWM_PWMHW__CNT_CMP0)
   #define PhaseGen1_PhasePWM_COUNTER_LSB_PTR     ( (reg16 *) PhaseGen1_PhasePWM_PWMHW__CNT_CMP0)
   #define PhaseGen1_PhasePWM_CAPTURE_LSB         (*(reg16 *) PhaseGen1_PhasePWM_PWMHW__CAP0)
   #define PhaseGen1_PhasePWM_CAPTURE_LSB_PTR     ( (reg16 *) PhaseGen1_PhasePWM_PWMHW__CAP0)
   #define PhaseGen1_PhasePWM_RT1                 (*(reg8 *)  PhaseGen1_PhasePWM_PWMHW__RT1)
   #define PhaseGen1_PhasePWM_RT1_PTR             ( (reg8 *)  PhaseGen1_PhasePWM_PWMHW__RT1)
      
#else
   #if (PhaseGen1_PhasePWM_Resolution == 8u) /* 8bit - PWM */
	   
	   #if(PhaseGen1_PhasePWM_PWMModeIsCenterAligned)
	       #define PhaseGen1_PhasePWM_PERIOD_LSB      (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
	       #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR   ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #else
	       #define PhaseGen1_PhasePWM_PERIOD_LSB      (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
	       #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR   ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
	   #endif /* (PhaseGen1_PhasePWM_PWMModeIsCenterAligned) */
	   
	   #define PhaseGen1_PhasePWM_COMPARE1_LSB    (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
	   #define PhaseGen1_PhasePWM_COMPARE1_LSB_PTR ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
	   #define PhaseGen1_PhasePWM_COMPARE2_LSB    (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #define PhaseGen1_PhasePWM_COMPARE2_LSB_PTR ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #define PhaseGen1_PhasePWM_COUNTERCAP_LSB   (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
	   #define PhaseGen1_PhasePWM_COUNTERCAP_LSB_PTR ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
	   #define PhaseGen1_PhasePWM_COUNTER_LSB     (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
	   #define PhaseGen1_PhasePWM_COUNTER_LSB_PTR  ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
	   #define PhaseGen1_PhasePWM_CAPTURE_LSB     (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
	   #define PhaseGen1_PhasePWM_CAPTURE_LSB_PTR  ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
   
   #else
   		#if(CY_PSOC3) /* 8-bit address space */	
			#if(PhaseGen1_PhasePWM_PWMModeIsCenterAligned)
		       #define PhaseGen1_PhasePWM_PERIOD_LSB      (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
		       #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR   ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #else
		       #define PhaseGen1_PhasePWM_PERIOD_LSB      (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
		       #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR   ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F0_REG)
		    #endif /* (PhaseGen1_PhasePWM_PWMModeIsCenterAligned) */
		   
		    #define PhaseGen1_PhasePWM_COMPARE1_LSB    (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
		    #define PhaseGen1_PhasePWM_COMPARE1_LSB_PTR ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D0_REG)
		    #define PhaseGen1_PhasePWM_COMPARE2_LSB    (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #define PhaseGen1_PhasePWM_COMPARE2_LSB_PTR ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #define PhaseGen1_PhasePWM_COUNTERCAP_LSB   (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
		    #define PhaseGen1_PhasePWM_COUNTERCAP_LSB_PTR ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A1_REG)
		    #define PhaseGen1_PhasePWM_COUNTER_LSB     (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
		    #define PhaseGen1_PhasePWM_COUNTER_LSB_PTR  ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__A0_REG)
		    #define PhaseGen1_PhasePWM_CAPTURE_LSB     (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
		    #define PhaseGen1_PhasePWM_CAPTURE_LSB_PTR  ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__F1_REG)
		#else
			#if(PhaseGen1_PhasePWM_PWMModeIsCenterAligned)
		       #define PhaseGen1_PhasePWM_PERIOD_LSB      (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		       #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR   ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #else
		       #define PhaseGen1_PhasePWM_PERIOD_LSB      (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
		       #define PhaseGen1_PhasePWM_PERIOD_LSB_PTR   ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
		    #endif /* (PhaseGen1_PhasePWM_PWMModeIsCenterAligned) */
		   
		    #define PhaseGen1_PhasePWM_COMPARE1_LSB    (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
		    #define PhaseGen1_PhasePWM_COMPARE1_LSB_PTR ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
		    #define PhaseGen1_PhasePWM_COMPARE2_LSB    (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #define PhaseGen1_PhasePWM_COMPARE2_LSB_PTR ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #define PhaseGen1_PhasePWM_COUNTERCAP_LSB   (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
		    #define PhaseGen1_PhasePWM_COUNTERCAP_LSB_PTR ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
		    #define PhaseGen1_PhasePWM_COUNTER_LSB     (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
		    #define PhaseGen1_PhasePWM_COUNTER_LSB_PTR  ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
		    #define PhaseGen1_PhasePWM_CAPTURE_LSB     (*(reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
		    #define PhaseGen1_PhasePWM_CAPTURE_LSB_PTR  ((reg16 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
		#endif
		
	   #define PhaseGen1_PhasePWM_AUX_CONTROLDP1    (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define PhaseGen1_PhasePWM_AUX_CONTROLDP1_PTR  ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (PhaseGen1_PhasePWM_Resolution == 8) */
   
   #define PhaseGen1_PhasePWM_AUX_CONTROLDP0      (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define PhaseGen1_PhasePWM_AUX_CONTROLDP0_PTR  ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (PhaseGen1_PhasePWM_UsingFixedFunction) */
   
#if(PhaseGen1_PhasePWM_KillModeMinTime )
    #define PhaseGen1_PhasePWM_KILLMODEMINTIME      (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define PhaseGen1_PhasePWM_KILLMODEMINTIME_PTR   ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (PhaseGen1_PhasePWM_KillModeMinTime ) */

#if(PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_256_CLOCKS)
    #define PhaseGen1_PhasePWM_DEADBAND_COUNT      (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PhaseGen1_PhasePWM_DEADBAND_COUNT_PTR  ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PhaseGen1_PhasePWM_DEADBAND_LSB_PTR    ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define PhaseGen1_PhasePWM_DEADBAND_LSB        (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (PhaseGen1_PhasePWM_UsingFixedFunction)
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT        (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__CFG0) 
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT_PTR     ((reg8 *) PhaseGen1_PhasePWM_PWMHW__CFG0)
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PhaseGen1_PhasePWM_DEADBAND_COUNT_SHIFT)
        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT_SHIFT   0x06u  
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT        (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT_PTR     ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PhaseGen1_PhasePWM_DEADBAND_COUNT_SHIFT) 
        /* As defined by the verilog implementation of the Control Register */
        #define PhaseGen1_PhasePWM_DEADBAND_COUNT_SHIFT   0x00u 
    #endif /* (PhaseGen1_PhasePWM_UsingFixedFunction) */
#endif /* (PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_256_CLOCKS) */



#if (PhaseGen1_PhasePWM_UsingFixedFunction)
    #define PhaseGen1_PhasePWM_STATUS                (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__SR0)
    #define PhaseGen1_PhasePWM_STATUS_PTR            ((reg8 *) PhaseGen1_PhasePWM_PWMHW__SR0)
    #define PhaseGen1_PhasePWM_STATUS_MASK           (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__SR0)
    #define PhaseGen1_PhasePWM_STATUS_MASK_PTR       ((reg8 *) PhaseGen1_PhasePWM_PWMHW__SR0)
    #define PhaseGen1_PhasePWM_CONTROL               (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__CFG0)
    #define PhaseGen1_PhasePWM_CONTROL_PTR           ((reg8 *) PhaseGen1_PhasePWM_PWMHW__CFG0)    
    #define PhaseGen1_PhasePWM_CONTROL2              (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__CFG1)    
    #define PhaseGen1_PhasePWM_CONTROL3              (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__CFG2)
    #define PhaseGen1_PhasePWM_GLOBAL_ENABLE         (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__PM_ACT_CFG)
    #define PhaseGen1_PhasePWM_GLOBAL_ENABLE_PTR       ( (reg8 *) PhaseGen1_PhasePWM_PWMHW__PM_ACT_CFG)
    #define PhaseGen1_PhasePWM_GLOBAL_STBY_ENABLE      (*(reg8 *) PhaseGen1_PhasePWM_PWMHW__PM_STBY_CFG)
    #define PhaseGen1_PhasePWM_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) PhaseGen1_PhasePWM_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define PhaseGen1_PhasePWM_BLOCK_EN_MASK          PhaseGen1_PhasePWM_PWMHW__PM_ACT_MSK
    #define PhaseGen1_PhasePWM_BLOCK_STBY_EN_MASK     PhaseGen1_PhasePWM_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define PhaseGen1_PhasePWM_CTRL_ENABLE_SHIFT      0x00u
    
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    
    #define PhaseGen1_PhasePWM_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */

    /* Fixed Function Block Only CFG register bit definitions */
    #define PhaseGen1_PhasePWM_CFG0_MODE              0x02u   /*  Set to compare mode */
    
    /* #define PhaseGen1_PhasePWM_CFG0_ENABLE            0x01u */  /* Enable the block to run */
    #define PhaseGen1_PhasePWM_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define PhaseGen1_PhasePWM_CTRL_ENABLE            (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_CTRL_ENABLE_SHIFT)
    #define PhaseGen1_PhasePWM_CTRL_RESET             (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_CTRL_RESET_SHIFT)
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PhaseGen1_PhasePWM_CTRL_CMPMODE2_SHIFT)
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PhaseGen1_PhasePWM_CTRL_CMPMODE1_SHIFT)
    
    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define PhaseGen1_PhasePWM_CTRL2_IRQ_SEL_SHIFT    0x00u       
    #define PhaseGen1_PhasePWM_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define PhaseGen1_PhasePWM_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define PhaseGen1_PhasePWM_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define PhaseGen1_PhasePWM_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define PhaseGen1_PhasePWM_STATUS_TC_INT_EN_MASK_SHIFT            (PhaseGen1_PhasePWM_STATUS_TC_SHIFT - 4u)
    #define PhaseGen1_PhasePWM_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define PhaseGen1_PhasePWM_STATUS_CMP1_INT_EN_MASK_SHIFT          (PhaseGen1_PhasePWM_STATUS_CMP1_SHIFT - 4u)
    
    /* Status Register Bit Masks */
    #define PhaseGen1_PhasePWM_STATUS_TC              (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_TC_SHIFT)
    #define PhaseGen1_PhasePWM_STATUS_CMP1            (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks */
    #define PhaseGen1_PhasePWM_STATUS_TC_INT_EN_MASK              (uint8)((uint8)PhaseGen1_PhasePWM_STATUS_TC >> 4u)
    #define PhaseGen1_PhasePWM_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)PhaseGen1_PhasePWM_STATUS_CMP1 >> 4u)
    
    /*RT1 Synch Constants */
    #define PhaseGen1_PhasePWM_RT1_SHIFT             0x04u
    #define PhaseGen1_PhasePWM_RT1_MASK              (uint8)((uint8)0x03u << PhaseGen1_PhasePWM_RT1_SHIFT)/* Sync TC and CMP bit masks */
    #define PhaseGen1_PhasePWM_SYNC                  (uint8)((uint8)0x03u << PhaseGen1_PhasePWM_RT1_SHIFT)
    #define PhaseGen1_PhasePWM_SYNCDSI_SHIFT         0x00u
    #define PhaseGen1_PhasePWM_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << PhaseGen1_PhasePWM_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define PhaseGen1_PhasePWM_SYNCDSI_EN            (uint8)((uint8)0x0Fu << PhaseGen1_PhasePWM_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define PhaseGen1_PhasePWM_STATUS                (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define PhaseGen1_PhasePWM_STATUS_PTR            ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define PhaseGen1_PhasePWM_STATUS_MASK           (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__MASK_REG)
    #define PhaseGen1_PhasePWM_STATUS_MASK_PTR       ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__MASK_REG)
    #define PhaseGen1_PhasePWM_STATUS_AUX_CTRL       (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define PhaseGen1_PhasePWM_CONTROL               (*(reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define PhaseGen1_PhasePWM_CONTROL_PTR           ((reg8 *) PhaseGen1_PhasePWM_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/

    /* Control Register definitions */
    #define PhaseGen1_PhasePWM_CTRL_ENABLE_SHIFT      0x07u
    #define PhaseGen1_PhasePWM_CTRL_RESET_SHIFT       0x06u
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE2_SHIFT    0x03u
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE1_SHIFT    0x00u
    #define PhaseGen1_PhasePWM_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define PhaseGen1_PhasePWM_CTRL_ENABLE            (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_CTRL_ENABLE_SHIFT)
    #define PhaseGen1_PhasePWM_CTRL_RESET             (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_CTRL_RESET_SHIFT)
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PhaseGen1_PhasePWM_CTRL_CMPMODE2_SHIFT)
    #define PhaseGen1_PhasePWM_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PhaseGen1_PhasePWM_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define PhaseGen1_PhasePWM_STATUS_KILL_SHIFT          0x05u
    #define PhaseGen1_PhasePWM_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define PhaseGen1_PhasePWM_STATUS_FIFOFULL_SHIFT      0x03u  
    #define PhaseGen1_PhasePWM_STATUS_TC_SHIFT            0x02u
    #define PhaseGen1_PhasePWM_STATUS_CMP2_SHIFT          0x01u
    #define PhaseGen1_PhasePWM_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define PhaseGen1_PhasePWM_STATUS_KILL_INT_EN_MASK_SHIFT          PhaseGen1_PhasePWM_STATUS_KILL_SHIFT          
    #define PhaseGen1_PhasePWM_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    PhaseGen1_PhasePWM_STATUS_FIFONEMPTY_SHIFT    
    #define PhaseGen1_PhasePWM_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      PhaseGen1_PhasePWM_STATUS_FIFOFULL_SHIFT        
    #define PhaseGen1_PhasePWM_STATUS_TC_INT_EN_MASK_SHIFT            PhaseGen1_PhasePWM_STATUS_TC_SHIFT            
    #define PhaseGen1_PhasePWM_STATUS_CMP2_INT_EN_MASK_SHIFT          PhaseGen1_PhasePWM_STATUS_CMP2_SHIFT          
    #define PhaseGen1_PhasePWM_STATUS_CMP1_INT_EN_MASK_SHIFT          PhaseGen1_PhasePWM_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define PhaseGen1_PhasePWM_STATUS_KILL            (uint8)((uint8)0x00u << PhaseGen1_PhasePWM_STATUS_KILL_SHIFT )
    #define PhaseGen1_PhasePWM_STATUS_FIFOFULL        (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_FIFOFULL_SHIFT)
    #define PhaseGen1_PhasePWM_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_FIFONEMPTY_SHIFT)
    #define PhaseGen1_PhasePWM_STATUS_TC              (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_TC_SHIFT)
    #define PhaseGen1_PhasePWM_STATUS_CMP2            (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_CMP2_SHIFT) 
    #define PhaseGen1_PhasePWM_STATUS_CMP1            (uint8)((uint8)0x01u << PhaseGen1_PhasePWM_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define PhaseGen1_PhasePWM_STATUS_KILL_INT_EN_MASK            PhaseGen1_PhasePWM_STATUS_KILL
    #define PhaseGen1_PhasePWM_STATUS_FIFOFULL_INT_EN_MASK        PhaseGen1_PhasePWM_STATUS_FIFOFULL
    #define PhaseGen1_PhasePWM_STATUS_FIFONEMPTY_INT_EN_MASK      PhaseGen1_PhasePWM_STATUS_FIFONEMPTY
    #define PhaseGen1_PhasePWM_STATUS_TC_INT_EN_MASK              PhaseGen1_PhasePWM_STATUS_TC
    #define PhaseGen1_PhasePWM_STATUS_CMP2_INT_EN_MASK            PhaseGen1_PhasePWM_STATUS_CMP2
    #define PhaseGen1_PhasePWM_STATUS_CMP1_INT_EN_MASK            PhaseGen1_PhasePWM_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define PhaseGen1_PhasePWM_AUX_CTRL_FIFO0_CLR     0x01u
    #define PhaseGen1_PhasePWM_AUX_CTRL_FIFO1_CLR     0x02u
    #define PhaseGen1_PhasePWM_AUX_CTRL_FIFO0_LVL     0x04u
    #define PhaseGen1_PhasePWM_AUX_CTRL_FIFO1_LVL     0x08u
    #define PhaseGen1_PhasePWM_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* PhaseGen1_PhasePWM_UsingFixedFunction */

#endif  /* CY_PWM_PhaseGen1_PhasePWM_H */


/* [] END OF FILE */
