/*******************************************************************************
* File Name: PhaseGen1_PhasePWM_PM.c
* Version 3.0
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "PhaseGen1_PhasePWM.h"

static PhaseGen1_PhasePWM_backupStruct PhaseGen1_PhasePWM_backup;


/*******************************************************************************
* Function Name: PhaseGen1_PhasePWM_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PhaseGen1_PhasePWM_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void PhaseGen1_PhasePWM_SaveConfig(void) 
{
    
    #if(!PhaseGen1_PhasePWM_UsingFixedFunction)
        #if(!PhaseGen1_PhasePWM_PWMModeIsCenterAligned)
            PhaseGen1_PhasePWM_backup.PWMPeriod = PhaseGen1_PhasePWM_ReadPeriod();
        #endif /* (!PhaseGen1_PhasePWM_PWMModeIsCenterAligned) */
        PhaseGen1_PhasePWM_backup.PWMUdb = PhaseGen1_PhasePWM_ReadCounter();
        #if (PhaseGen1_PhasePWM_UseStatus)
            PhaseGen1_PhasePWM_backup.InterruptMaskValue = PhaseGen1_PhasePWM_STATUS_MASK;
        #endif /* (PhaseGen1_PhasePWM_UseStatus) */
        
        #if(PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_256_CLOCKS || \
            PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_2_4_CLOCKS)
            PhaseGen1_PhasePWM_backup.PWMdeadBandValue = PhaseGen1_PhasePWM_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */
        
        #if(PhaseGen1_PhasePWM_KillModeMinTime)
             PhaseGen1_PhasePWM_backup.PWMKillCounterPeriod = PhaseGen1_PhasePWM_ReadKillTime();
        #endif /* (PhaseGen1_PhasePWM_KillModeMinTime) */
        
        #if(PhaseGen1_PhasePWM_UseControl)
            PhaseGen1_PhasePWM_backup.PWMControlRegister = PhaseGen1_PhasePWM_ReadControlRegister();
        #endif /* (PhaseGen1_PhasePWM_UseControl) */
    #endif  /* (!PhaseGen1_PhasePWM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PhaseGen1_PhasePWM_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PhaseGen1_PhasePWM_backup:  Variables of this global structure are used to  
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void PhaseGen1_PhasePWM_RestoreConfig(void) 
{
        #if(!PhaseGen1_PhasePWM_UsingFixedFunction)
            #if(!PhaseGen1_PhasePWM_PWMModeIsCenterAligned)
                PhaseGen1_PhasePWM_WritePeriod(PhaseGen1_PhasePWM_backup.PWMPeriod);
            #endif /* (!PhaseGen1_PhasePWM_PWMModeIsCenterAligned) */
            PhaseGen1_PhasePWM_WriteCounter(PhaseGen1_PhasePWM_backup.PWMUdb);
            #if (PhaseGen1_PhasePWM_UseStatus)
                PhaseGen1_PhasePWM_STATUS_MASK = PhaseGen1_PhasePWM_backup.InterruptMaskValue;
            #endif /* (PhaseGen1_PhasePWM_UseStatus) */
            
            #if(PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_256_CLOCKS || \
                PhaseGen1_PhasePWM_DeadBandMode == PhaseGen1_PhasePWM__B_PWM__DBM_2_4_CLOCKS)
                PhaseGen1_PhasePWM_WriteDeadTime(PhaseGen1_PhasePWM_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
            #if(PhaseGen1_PhasePWM_KillModeMinTime)
                PhaseGen1_PhasePWM_WriteKillTime(PhaseGen1_PhasePWM_backup.PWMKillCounterPeriod);
            #endif /* (PhaseGen1_PhasePWM_KillModeMinTime) */
            
            #if(PhaseGen1_PhasePWM_UseControl)
                PhaseGen1_PhasePWM_WriteControlRegister(PhaseGen1_PhasePWM_backup.PWMControlRegister); 
            #endif /* (PhaseGen1_PhasePWM_UseControl) */
        #endif  /* (!PhaseGen1_PhasePWM_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: PhaseGen1_PhasePWM_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PhaseGen1_PhasePWM_backup.PWMEnableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void PhaseGen1_PhasePWM_Sleep(void) 
{
    #if(PhaseGen1_PhasePWM_UseControl)
        if(PhaseGen1_PhasePWM_CTRL_ENABLE == (PhaseGen1_PhasePWM_CONTROL & PhaseGen1_PhasePWM_CTRL_ENABLE))
        {
            /*Component is enabled */
            PhaseGen1_PhasePWM_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            PhaseGen1_PhasePWM_backup.PWMEnableState = 0u;
        }
    #endif /* (PhaseGen1_PhasePWM_UseControl) */

    /* Stop component */
    PhaseGen1_PhasePWM_Stop();
    
    /* Save registers configuration */
    PhaseGen1_PhasePWM_SaveConfig();
}


/*******************************************************************************
* Function Name: PhaseGen1_PhasePWM_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PhaseGen1_PhasePWM_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void PhaseGen1_PhasePWM_Wakeup(void) 
{
     /* Restore registers values */
    PhaseGen1_PhasePWM_RestoreConfig();
    
    if(PhaseGen1_PhasePWM_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        PhaseGen1_PhasePWM_Enable();
    } /* Do nothing if component's block was disabled before */
    
}


/* [] END OF FILE */
