/*******************************************************************************
* File Name: PinOut.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinOut.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PinOut__PORT == 15 && ((PinOut__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PinOut_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PinOut_Write(uint8 value) 
{
    uint8 staticBits = (PinOut_DR & (uint8)(~PinOut_MASK));
    PinOut_DR = staticBits | ((uint8)(value << PinOut_SHIFT) & PinOut_MASK);
}


/*******************************************************************************
* Function Name: PinOut_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PinOut_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PinOut_0, mode);
	CyPins_SetPinDriveMode(PinOut_1, mode);
	CyPins_SetPinDriveMode(PinOut_2, mode);
	CyPins_SetPinDriveMode(PinOut_3, mode);
	CyPins_SetPinDriveMode(PinOut_4, mode);
	CyPins_SetPinDriveMode(PinOut_5, mode);
	CyPins_SetPinDriveMode(PinOut_6, mode);
	CyPins_SetPinDriveMode(PinOut_7, mode);
}


/*******************************************************************************
* Function Name: PinOut_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinOut_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinOut_Read(void) 
{
    return (PinOut_PS & PinOut_MASK) >> PinOut_SHIFT;
}


/*******************************************************************************
* Function Name: PinOut_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinOut_ReadDataReg(void) 
{
    return (PinOut_DR & PinOut_MASK) >> PinOut_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinOut_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinOut_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinOut_ClearInterrupt(void) 
    {
        return (PinOut_INTSTAT & PinOut_MASK) >> PinOut_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
