/*******************************************************************************
* File Name: PinPhase.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinPhase.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PinPhase__PORT == 15 && ((PinPhase__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PinPhase_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PinPhase_Write(uint8 value) 
{
    uint8 staticBits = (PinPhase_DR & (uint8)(~PinPhase_MASK));
    PinPhase_DR = staticBits | ((uint8)(value << PinPhase_SHIFT) & PinPhase_MASK);
}


/*******************************************************************************
* Function Name: PinPhase_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PinPhase_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PinPhase_0, mode);
	CyPins_SetPinDriveMode(PinPhase_1, mode);
	CyPins_SetPinDriveMode(PinPhase_2, mode);
	CyPins_SetPinDriveMode(PinPhase_3, mode);
	CyPins_SetPinDriveMode(PinPhase_4, mode);
	CyPins_SetPinDriveMode(PinPhase_5, mode);
	CyPins_SetPinDriveMode(PinPhase_6, mode);
	CyPins_SetPinDriveMode(PinPhase_7, mode);
}


/*******************************************************************************
* Function Name: PinPhase_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinPhase_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinPhase_Read(void) 
{
    return (PinPhase_PS & PinPhase_MASK) >> PinPhase_SHIFT;
}


/*******************************************************************************
* Function Name: PinPhase_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinPhase_ReadDataReg(void) 
{
    return (PinPhase_DR & PinPhase_MASK) >> PinPhase_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinPhase_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinPhase_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinPhase_ClearInterrupt(void) 
    {
        return (PinPhase_INTSTAT & PinPhase_MASK) >> PinPhase_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
