/*******************************************************************************
* File Name: PinSignal.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinSignal.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PinSignal__PORT == 15 && ((PinSignal__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PinSignal_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PinSignal_Write(uint8 value) 
{
    uint8 staticBits = (PinSignal_DR & (uint8)(~PinSignal_MASK));
    PinSignal_DR = staticBits | ((uint8)(value << PinSignal_SHIFT) & PinSignal_MASK);
}


/*******************************************************************************
* Function Name: PinSignal_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PinSignal_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PinSignal_0, mode);
}


/*******************************************************************************
* Function Name: PinSignal_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinSignal_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinSignal_Read(void) 
{
    return (PinSignal_PS & PinSignal_MASK) >> PinSignal_SHIFT;
}


/*******************************************************************************
* Function Name: PinSignal_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinSignal_ReadDataReg(void) 
{
    return (PinSignal_DR & PinSignal_MASK) >> PinSignal_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinSignal_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinSignal_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinSignal_ClearInterrupt(void) 
    {
        return (PinSignal_INTSTAT & PinSignal_MASK) >> PinSignal_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
