/*******************************************************************************
* File Name: StatusDiff.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware to read the value of a Status 
*  Register.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "StatusDiff.h"

#if !defined(StatusDiff_sts_sts_reg__REMOVED) /* Check for removal by optimization */


/*******************************************************************************
* Function Name: StatusDiff_Read
********************************************************************************
*
* Summary:
*  Reads the current value assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The current value in the Status Register.
*
*******************************************************************************/
uint8 StatusDiff_Read(void) 
{ 
    return StatusDiff_Status;
}


/*******************************************************************************
* Function Name: StatusDiff_InterruptEnable
********************************************************************************
*
* Summary:
*  Enables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void StatusDiff_InterruptEnable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    StatusDiff_Status_Aux_Ctrl |= StatusDiff_STATUS_INTR_ENBL;
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: StatusDiff_InterruptDisable
********************************************************************************
*
* Summary:
*  Disables the Status Register interrupt.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void StatusDiff_InterruptDisable(void) 
{
    uint8 interruptState;
    interruptState = CyEnterCriticalSection();
    StatusDiff_Status_Aux_Ctrl &= (uint8)(~StatusDiff_STATUS_INTR_ENBL);
    CyExitCriticalSection(interruptState);
}


/*******************************************************************************
* Function Name: StatusDiff_WriteMask
********************************************************************************
*
* Summary:
*  Writes the current mask value assigned to the Status Register.
*
* Parameters:
*  mask:  Value to write into the mask register.
*
* Return:
*  None.
*
*******************************************************************************/
void StatusDiff_WriteMask(uint8 mask) 
{
    #if(StatusDiff_INPUTS < 8u)
    	mask &= (uint8)((((uint8)1u) << StatusDiff_INPUTS) - 1u);
	#endif /* End StatusDiff_INPUTS < 8u */
    StatusDiff_Status_Mask = mask;
}


/*******************************************************************************
* Function Name: StatusDiff_ReadMask
********************************************************************************
*
* Summary:
*  Reads the current interrupt mask assigned to the Status Register.
*
* Parameters:
*  None.
*
* Return:
*  The value of the interrupt mask of the Status Register.
*
*******************************************************************************/
uint8 StatusDiff_ReadMask(void) 
{
    return StatusDiff_Status_Mask;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
